<!doctype style-sheet PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN">
<style-sheet>
<style-specification>
<style-specification-body>

;; ######################################################################
;;
;; DSSSL style sheet for slides
;;
;; Started 1998.03.26
;;
;; Richard Light
;;
;; ######################################################################

;; .......................... Paragraphs .............................

 (element PARA (STANDARD-PARAGRAPH))

 (element ITEM (STANDARD-PARAGRAPH))

 (element EXAMPLE (MONO-PARAGRAPH))

;; ........................... Emphasis ...............................

 (element EMPH (HIGHLIGHTED-PHRASE "italic"))

;; ........................... LISTS ..................................

(element LIST1 (STANDARD-LIST))

(element LITEM (STANDARD-LIST-ITEM))

;; .......................... Slides ..............................

(element SLIDE (DISPLAYSLIDE))

(element (SLIDE HEAD)
  (make box
    (OUTPUT-HEADING 20pt)))

;; ....................... FRONT MATTER ...........................

(element TITLE (OUTPUT-HEADING 30pt))

(element TEXT (OUTPUT-HEADING 16pt))

;; .............................. UNITS ...........................

(define-unit mm .001m)
(define-unit cm .01m)
(define-unit in 2.54cm)
(define-unit pi (/ 1in 6))
(define-unit pt (/ 1in 72))
(define-unit px (/ 1in 96))

;; see below for definition of "em"


;; ....................... UNITS AND PARAMETERS ...................

(define *bf-size* 12pt)
(define-unit em *bf-size*)

;; these font selections are for Windows 95

(define *title-font-family* "Arial")
(define *body-font-family* "Times New Roman")
(define *mono-font-family* "Courier New")

;; special characters to be inserted into the output.  These entities are
;; represented as Unicode hexadecimal character values, which Jade can interpret
;; directly:
(define *disk-bullet* "\U-2022")
(define *triangle-bullet* "\U-2023")
(define *circle-bullet* "\U-25EF")
(define *square-bullet* "\U-2580")
(define *small-diamond-bullet* "\U-25C6")
(define *ldquo* "\left-double-quotation-mark")
(define *rdquo* "\right-double-quotation-mark")
(define *emsp* "\U-1F9F")


(define *line-spacing-factor* 1.1)
(define *head-before-factor* 0.75)
(define *head-after-factor* 0.5)
;(define *autonum-level* 6) ;; zero disables autonumbering

(define *page-width* 8.25in)
(define *page-height* 11.5in)
(define *left-right-margin* 6pi)
(define *top-margin*    7.5pi)
(define *bottom-margin* 7.5pi)
(define *header-margin* 4.5pi)
(define *footer-margin* 4.5pi)

(define *text-width* (- *page-width* (* *left-right-margin* 2)))
(define *body-start-indent* 3pi)
(define *body-width* (- *text-width* *body-start-indent*))
(define *para-sep* (/ *bf-size* 2.0))
(define *block-sep* (* *para-sep* 2.0))
(define *hsize-bump-factor* 1.2)

(define *rgb-color-space*
  (color-space "ISO/IEC 10179:1996//Color-Space Family::Device RGB"))


;; ........................... FUNCTIONS .............................

(define p-style
  (style
   font-size: *bf-size*
   line-spacing: (* *bf-size* *line-spacing-factor*)))

(define (INLIST?)
  (or
    (equal? (gi (parent (parent))) "LIST1")
    (equal? (gi (parent (parent))) "LIST2")))

(define (DISPLAYSLIDE)
  (make sequence
    (if (= (child-number) 1)
         (make-table-of-contents)
         (empty-sosofo))
    (make display-group
          space-before: 50pt
          quadding: 'start
          keep: #t
          (process-children-trim))))

(define (PAGE-NUMBER-HEADING)
  (make sequence
	font-size: (- *bf-size* 1pt)
	line-spacing: (* (- *bf-size* 1pt) *line-spacing-factor*)
  	(literal "Page ")
	(page-number-sosofo)))

(define (STANDARD-PAGE-SEQUENCE)
 (make simple-page-sequence
       font-family-name: *body-font-family*
       font-size: *bf-size*
       font-weight: 'medium
       font-posture: 'upright
       line-spacing: (* *bf-size* *line-spacing-factor*)
       left-header: (CURRENT-SECTION-HEADING)
       left-footer: (DOCUMENT-TITLE-HEADING)
       right-footer: (PAGE-NUMBER-HEADING)
       top-margin: *top-margin*
       bottom-margin: *bottom-margin*
       left-margin: *left-right-margin*
       right-margin: *left-right-margin*
       header-margin: *header-margin*
       footer-margin: *footer-margin*
       page-width: *page-width*
       page-height: *page-height*
       input-whitespace-treatment: 'collapse
       quadding: 'justify
       start-indent: *body-start-indent*
       content-map: '((endnotes #f))
       (make sequence
             (process-children-trim))))


(define (number-clause-sosofo node)
  (literal
   (format-number-list (reverse (number-clause node))
		       "1"
		       ".")))

(define (number-clause node)
  (list (child-number node)))

(define (EMPH-WEIGHT emphasis)
  (if (string? emphasis)
    (case emphasis
          (("light") 'light)
          (("li") 'light)
          (("bo") 'bold)
          (("bold") 'bold)
          (("sc") 'bold) ; best we can do for small caps for now: see the glyph-id property
          (else 'medium))
    'medium))

(define (EMPH-POSTURE emphasis)
  (if (string? emphasis)
    (case emphasis
          (("oblique") 'oblique)
          (("ob") 'oblique)
          (("italic") 'italic)
          (("it") 'italic)
          (else 'upright))
    'upright))

;; .......................... PARAGRAPH STYLES .......................

(define (STANDARD-PARAGRAPH)
 (make paragraph
       use: p-style
       space-before: *para-sep*
       quadding: 'start
       (process-children-trim)))

(define (ITALIC-CENTRED-PARAGRAPH)
  (make paragraph
	use: p-style
	space-before: (* *para-sep* 2)
	quadding: 'center
	font-posture: 'italic
	(process-children-trim)))

(define (MONO-PARAGRAPH)
  (make paragraph
        line-spacing: (* *bf-size* *line-spacing-factor*)
	space-before: (if (= (child-number) 1) *para-sep* 0pt)
	start-indent: (+ (inherited-start-indent) 1em)
        lines: 'asis
	font-family-name: *mono-font-family*
        quadding: 'start
	input-whitespace-treatment: 'preserve
        (process-children-trim)))

(define (HIGHLIGHTED-PHRASE rend)
  (make sequence
        font-weight: (EMPH-WEIGHT rend)
        font-posture: (EMPH-POSTURE rend)
        (process-children-trim)))

(define (STANDARD-LINE-GROUP)
  (make paragraph
	use: p-style
	space-before: (* *para-sep* 2)
	start-indent: (* (inherited-start-indent) 2)
	quadding: 'start
	(process-children-trim)))


;; ................ [DIVn] Headings  .................

(define (OUTPUT-HEADING headsize)
  (make paragraph
	font-family-name: *title-font-family*
	font-weight: 'bold
	font-size: headsize
	line-spacing: (* headsize *line-spacing-factor*)
	space-before: (* headsize *head-before-factor*)
	space-after: (* headsize *head-after-factor*)
	quadding: 'center
	keep-with-next?: #t
	(process-children-trim)))


(define (SPECIFIC-HEADING value headsize)
  (make paragraph
	font-family-name: *title-font-family*
	font-weight: 'bold
	font-size: headsize
	line-spacing: (* headsize *line-spacing-factor*)
	space-before: (* headsize *head-before-factor*)
	space-after: (* headsize *head-after-factor*)
	quadding: 'center
	keep-with-next?: #t
	(literal value)))


;; ...................... lists ...............................

(define (STANDARD-LIST)
 (make paragraph
       space-before: (if (INLIST?)
			 *para-sep*
		         *block-sep*)
       space-after:  (if (INLIST?)
			 *para-sep*
		         *block-sep*)
       start-indent: (if (INLIST?)
			 (+ (inherited-start-indent) 10pt)
		         (inherited-start-indent))
       (process-children-trim)))

(define (STANDARD-LIST-ITEM)
 (make paragraph
       use: p-style
       space-before: *para-sep*
       (make line-field
	     font-family-name: *body-font-family*
	     font-size: *bf-size*
	     field-width: 10pt
	     (literal *disk-bullet*))
       (process-children-trim)))

;;..............................TABLE OF CONTENTS.................................

(define (make-table-of-contents)
  (make table
        table-width: *text-width*
        space-before: 30pt
        use: p-style
    (make table-cell
          n-columns-spanned: 8
      (SPECIFIC-HEADING "CONTENTS" 20pt))
    (with-mode toc
      (process-node-list (ancestor "slideset" (current-node))))))

(define (toc-entry)
  (make sequence
    (make table-cell
          starts-row?: #t
          cell-before-row-margin: (/ *bf-size* 2)
          n-columns-spanned: 7
      (STANDARD-PARAGRAPH))
    (make table-cell
          ends-row?: #t
      (make paragraph
            use: p-style
            space-before: *para-sep*
            quadding: 'end
        (current-node-page-number-sosofo)))))


(mode toc
  (element (SLIDESET SLIDE HEAD) (toc-entry))
  (element SLIDESET (process-children-trim))
  (element SLIDE (process-children-trim))
  (default (empty-sosofo)))

</style-specification-body>
</style-specification>
</style-sheet>
